function [output_G, output_R, output_stimulation, output_raw_analyzed, output_E] = fun_raw_analysis_stimulation...
            (input_G_raw, input_G_marker_raw, input_G_exposure_n, input_G_baseline_n, ...
                input_G_afterLED_n, input_G_average_n, input_G_subtraction_check,...
                    input_R_raw, input_R_marker_raw, input_R_exposure_n, input_R_baseline_n, ...
                        input_R_afterLED_n, input_R_average_n, input_R_subtraction_check,...
                            input_analyze_index, input_stimulation_marker_raw)
    
%% find index
    stimulation_marker_n = length(input_stimulation_marker_raw);
    G_marker_n = length(input_G_marker_raw);
    if stimulation_marker_n < G_marker_n % in case the the stimulation is shorter because the recording stopped during the last stimulation cycle
        input_stimulation_marker_raw(stimulation_marker_n+1: G_marker_n) = 0;
    end
    errorcheck = 0;
    output_E(1,10) = "";
    output_E(1,1) = "";
    start_pattern = [0,0,0,0,1,1,1,1]; % pattern to define startpoint
    end_pattern = [1,1,1,1,0,0,0,0]; % pattern to define endpoint    
    G_binary(1,:) = input_G_marker_raw > 3; % change data to binary
    G_endpoint = strfind(G_binary, end_pattern) + 3; % find the endpoint in green channel
    if isempty(G_endpoint)% return if there is no events        
        output_G = [];
        output_R = [];
        output_stimulation = [];
        output_raw_analyzed = 0;        
        return;
    end        
    G_startpoint = strfind(G_binary(1: max(G_endpoint)), start_pattern) + 4; % find the startpoint in green channel
    
    R_binary(1,:) = (input_R_marker_raw(1:max(G_endpoint)) > 3); % change data to binary
    R_startpoint = strfind(R_binary, start_pattern) + 4; % find the startpoint in red channel
    R_endpoint = strfind(R_binary, end_pattern) + 3; % find the endpoint in green channel
    
    stimulation_startpoint = strfind(input_stimulation_marker_raw', start_pattern); % find the start point of stimulation
    stimulation_endpoint = strfind(input_stimulation_marker_raw', end_pattern); % find the start point of stimulation
       
    output_stimulation = zeros(length(G_startpoint),1);
    for i = 1 : length(stimulation_endpoint)    
        distance_stimulation_startpoint_to_G_startpoint = abs(G_startpoint - stimulation_startpoint(i));
        distance_stimulation_endpoint_to_G_endpoint = abs(G_endpoint - stimulation_endpoint(i));
        [~, temp_stimulation_start] = min(distance_stimulation_startpoint_to_G_startpoint);
        [~, temp_stimulation_end] = min(distance_stimulation_endpoint_to_G_endpoint);
        output_stimulation(temp_stimulation_start:temp_stimulation_end) = 1;
    end
    
    %% quality control
    
    if length(G_startpoint) ~= length(G_endpoint)
        errorcheck = 2;
        output_E(1,errorcheck) = "startpoint and endpoint do not match in green_raw";        
    end
    if length(R_startpoint) ~= length(R_endpoint)
        errorcheck = 3;
        output_E(1,errorcheck) = "startpoint and endpoint do not match in red_raw";  
    end
    if length(G_startpoint) ~= length(R_startpoint)
        errorcheck = 4;
        output_E(1,errorcheck) = "green_raw and red_raw do not match"; 
    end
    if (max(G_endpoint - G_startpoint) > input_G_exposure_n + 4) || (min(G_endpoint - G_startpoint) < input_G_exposure_n - 4)
        errorcheck = 5;
        output_E(1,errorcheck) = "G_LED duration unstable"; 
    end
    
    if (max(R_endpoint - R_startpoint) > input_R_exposure_n + 4) || (min(R_endpoint - R_startpoint) < input_R_exposure_n - 4)
        errorcheck = 6;
        output_E(1,errorcheck) = "R_LED duration unstable"; 
    end
    if input_G_afterLED_n + input_G_average_n > min(G_endpoint - G_startpoint)
        errorcheck = 7;
        output_E(1,errorcheck) = "G average window too long"; 
    end
    if input_R_afterLED_n + input_R_average_n > min(R_endpoint - R_startpoint)
        errorcheck = 8;
        output_E(1,errorcheck) = "R average window too long"; 
    end
    if input_G_baseline_n > min(G_startpoint)
        errorcheck = 9;
        output_E(1,errorcheck) = "G baseline too long"; 
    end
    if input_R_baseline_n > min(R_startpoint)
        errorcheck = 10;
        output_E(1,10) = "R baseline too long"; 
    end

   %% 
    if errorcheck ~=0   % assign 0 to the results if there are errors, output length determined by green channel        
        output_G(1:length(G_endpoint),1) = 0;
        output_R(1:length(G_endpoint),1) = 0;
        output_E(1,1) = num2str(input_analyze_index);  % position of error in raw data
        output_raw_analyzed = 0; 
        return;
    end
    
    if ~isempty(G_startpoint)
        for i = 1:length(G_startpoint)
            output_G(i) = mean(input_G_raw(G_startpoint(i)+input_G_afterLED_n:G_startpoint(i)+input_G_afterLED_n+input_G_average_n)); % calculate mean value in the pulse 
            output_R(i) = mean(input_R_raw(R_startpoint(i)+input_R_afterLED_n:R_startpoint(i)+input_R_afterLED_n+input_R_average_n)); 
            output_g_baseline(i) = mean(input_G_raw(G_startpoint(i)-input_G_baseline_n-1:G_startpoint(i)-1)); % calculate baseline value in the pulse
            output_r_baseline(i) = mean(input_R_raw(R_startpoint(i)-input_R_baseline_n-1:R_startpoint(i)-1));
        end

        if input_G_subtraction_check == 1  % subtract baseline for green channel
            output_G = output_G - output_g_baseline;
        end

        if input_R_subtraction_check == 1 % subtract baseline for red channel
            output_R = output_R - output_r_baseline;
        end

        output_G = output_G';
        output_R = output_R';
        output_raw_analyzed = max(G_endpoint); % endpoint of current analysis      
    else
        output_G = [];
        output_R = [];
        output_raw_analyzed = 0;
    end
        
    
    
    
    
    
end

